@@ -44,11 +44,6 @@
 # #########################################################################
 from aps.common.singleton import Singleton, synchronized_method
 import sys, io, numpy
-try:
-    import termcolor
-    has_color = True
-except:
-    has_color = False
 
 DEFAULT_STREAM=sys.stdout
 
@@ -253,18 +248,15 @@ class __FullLogger(LoggerFacade):
     def __init__(self, stream=DEFAULT_STREAM):
         self.__stream = stream
 
-        if has_color:
-            if platform.system() == 'Windows':
-                self.__color_active = False
-            else:
-                if stream == DEFAULT_STREAM:
-                    self.__color_active = True
-                elif isinstance(stream, LogStream):
-                    self.__color_active = stream.is_color_active()
-                else:
-                    self.__color_active = False
-        else:
+        if platform.system() == 'Windows':
             self.__color_active = False
+        else:
+            if stream == DEFAULT_STREAM:
+                self.__color_active = True
+            elif isinstance(stream, LogStream):
+                self.__color_active = stream.is_color_active()
+            else:
+                self.__color_active = False
 
     def print(self, message):
         self.__stream.write(message + "\n")
